==> pygpt_net-2.0.165-py3-none-any.whl: pygpt_net/provider/audio_input/google_speech_recognition.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ================================================== #
# This file is a part of PYGPT package               #
# Website: https://pygpt.net                         #
# GitHub:  https://github.com/szczyglis-dev/py-gpt   #
# MIT License                                        #
# Created By  : Marcin Szczygliński                  #
# Updated Date: 2024.02.25 01:00:00                  #
# ================================================== #

import speech_recognition as sr

from .base import BaseProvider
from pygpt_net.utils import parse_args


class GoogleSpeechRecognition(BaseProvider):
    def __init__(self, *args, **kwargs):
        """
        Goggle (via Speech Recognition) provider

        :param args: args
        :param kwargs: kwargs
        """
        super(GoogleSpeechRecognition, self).__init__(*args, **kwargs)
        self.plugin = kwargs.get("plugin")
        self.id = "google_speech_recognition"
        self.name = "Google"

    def init_options(self):
        """Initialize options"""
        url_docs = {
            "Reference": "https://github.com/Uberi/speech_recognition/blob/master/reference/library-reference.rst",
        }
        self.plugin.add_option(
            "google_args",
            type="dict",
            value="",
            keys={
                'name': 'text',
                'value': 'text',
                'type': {
                    "type": "combo",
                    "use": "var_types",
                },
            },
            label="Additional keywords arguments",
            description="Additional keywords arguments for r.recognize_google(audio, **kwargs)",
            tooltip="Provide additional keywords arguments for recognize_google()",
            tab="google_speech_recognition",
            urls=url_docs,
        )

    def transcribe(self, path: str) -> str:
        """
        Audio to text transcription

        :param path: path to audio file to transcribe
        :return: transcribed text
        """
        args = {}
        additional_args = parse_args(self.plugin.get_option_value('google_args'))
        if additional_args:
            args.update(additional_args)

        r = sr.Recognizer()
        file = sr.AudioFile(path)
        with file as source:
            audio = r.record(source)
        return r.recognize_google(audio, **args)

    def is_configured(self) -> bool:
        """
        Check if provider is configured

        :return: True if configured, False otherwise
        """
        return True

    def get_config_message(self) -> str:
        """
        Return message to display when provider is not configured

        :return: message
        """
        return ""

==> pygpt_net-2.0.167-py3-none-any.whl: pygpt_net/provider/audio_input/google_speech_recognition.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ================================================== #
# This file is a part of PYGPT package               #
# Website: https://pygpt.net                         #
# GitHub:  https://github.com/szczyglis-dev/py-gpt   #
# MIT License                                        #
# Created By  : Marcin Szczygliński                  #
# Updated Date: 2024.02.25 01:00:00                  #
# ================================================== #

import speech_recognition as sr

from .base import BaseProvider
from pygpt_net.utils import parse_args


class GoogleSpeechRecognition(BaseProvider):
    def __init__(self, *args, **kwargs):
        """
        Goggle (via Speech Recognition) provider

        :param args: args
        :param kwargs: kwargs
        """
        super(GoogleSpeechRecognition, self).__init__(*args, **kwargs)
        self.plugin = kwargs.get("plugin")
        self.id = "google_speech_recognition"
        self.name = "Google"

    def init_options(self):
        """Initialize options"""
        url_docs = {
            "Help": "https://github.com/Uberi/speech_recognition/blob/master/reference/library-reference.rst",
        }
        self.plugin.add_option(
            "google_args",
            type="dict",
            value="",
            keys={
                'name': 'text',
                'value': 'text',
                'type': {
                    "type": "combo",
                    "use": "var_types",
                },
            },
            label="Additional keywords arguments",
            description="Additional keywords arguments for r.recognize_google(audio, **kwargs)",
            tooltip="Provide additional keywords arguments for recognize_google()",
            tab="google_speech_recognition",
            urls=url_docs,
        )

    def transcribe(self, path: str) -> str:
        """
        Audio to text transcription

        :param path: path to audio file to transcribe
        :return: transcribed text
        """
        args = {}
        additional_args = parse_args(self.plugin.get_option_value('google_args'))
        if additional_args:
            args.update(additional_args)

        r = sr.Recognizer()
        file = sr.AudioFile(path)
        with file as source:
            audio = r.record(source)
        return r.recognize_google(audio, **args)

    def is_configured(self) -> bool:
        """
        Check if provider is configured

        :return: True if configured, False otherwise
        """
        return True

    def get_config_message(self) -> str:
        """
        Return message to display when provider is not configured

        :return: message
        """
        return ""
